@@ -13,7 +13,7 @@ use Dancer2::Plugin::FormValidator::Input;
 use Dancer2::Plugin::FormValidator::Processor;
 use Types::Standard qw(InstanceOf);
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 plugin_keywords qw(validate validated errors);
 
@@ -70,11 +70,23 @@ sub validate {
     # We need to unset value of this var (if there was something).
     $self->clear_valid;
 
+    # Arguments.
     # Arguments.
     my $profile = $args{profile};
-    my $input   = $args{input} // $self->dsl->body_parameters->as_hashref_mixed;
+    my $input   = $args{input};
     my $lang    = $args{lang};
 
+    if (not defined $input) {
+        my $request = $self->app->request;
+
+        if ($request->is_get) {
+            $input = $request->query_parameters->as_hashref_mixed;
+        }
+        elsif($request->is_post) {
+            $input = $request->body_parameters->as_hashref_mixed;
+        }
+    }
+
     if (defined $lang) {
         $self->_validator_language($lang);
     }
@@ -172,7 +184,7 @@ Dancer2::Plugin::FormValidator - neat and easy to start form validation plugin f
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -325,7 +337,7 @@ Template app/register:
             </div>
             <div class="py-2">
                 <label class="block font-normal text-gray-400" for="email">
-                    Name
+                    Email
                 </label>
                 <input
                         type="text"
@@ -405,7 +417,7 @@ Key => values, where key is extension short name and values is its configuration
 
 =head3 validate
 
-    validate(Hash $params): HashRef|undef
+    validate(Hash %args): HashRef|undef
 
 Accept arguments as hash:
 
@@ -500,6 +512,14 @@ To set encoding to unicode you need to pass 'u' argument:
 
 Rule will be B</^\w+$/>.
 
+=head3 boolean
+
+    boolean(): Bool
+
+Validate that field is 0 or 1 scalar value.
+
+    field => [ qw(boolean) ]
+
 =head3 email
 
     email(): Bool
